@@ -139,6 +139,8 @@ typedef struct {
 	char **messages;
 } game_state;
 
+char *nki_file;
+
 /* global state */
 static game_state state;
 
@@ -197,7 +199,8 @@ static void read_file ( char *fname ) {
 			if ( ( ret == 0 ) || ( ch == '\n' ) || ( ch == '\r' ) )
 			{
 				/* ignore blank lines and comments */
-				if ( len != 0 && ( buff[0] != '#' ) ) {
+				if ( len != 0 && ( buff[0] != '#' ) 
+					&& ( buff[0] != '%')) {
 					buff[len] = '\0';
 					add_message ( buff, len + 1 );
 				}
@@ -224,9 +227,15 @@ static void do_read_messages ( char *dname ) {
 	struct dirent *dent;
 	struct stat sb;
 
+	if (nki_file != NULL) {
+	    read_file(nki_file);
+	    return;
+	}
+
 	/*@-mustfreefresh@ (this is a memory allocator) */
 	if ( ! ( dir = opendir ( dname ) ) ) return;
 	plen = strlen ( dname );
+
 	while ( ( dent = readdir ( dir ) ) ) {
 		len = plen + strlen ( dent->d_name ) + 2;
 		if ( ( fname = malloc ( len ) ) ==  NULL ) {
@@ -673,7 +682,7 @@ static void main_loop(void) {
 				y++; x++; break;
 	                case MYKEY_Q:
 	                case MYKEY_q:
-	                        finish ( EXIT_FAILURE );
+	                        finish ( EXIT_SUCCESS );
 	                        break;
 			case MYKEY_REDRAW:
 				draw_screen();
@@ -726,8 +735,11 @@ static void main_loop(void) {
 int main ( int argc, char **argv ) {
     int option, seed = (int) time ( 0 ), nbogus = DEFAULT_NUM_BOGUS;
 
-	while ((option = getopt(argc, argv, "n:s:Vh")) != -1) {
+	while ((option = getopt(argc, argv, "n:s:f:Vh")) != -1) {
 	    switch (option) {
+	    case 'f':
+		nki_file = strdup(optarg);
+		break;
 	    case 'n':
 		nbogus = atoi ( optarg );
 		if ( nbogus <= 0 ) {
@@ -744,7 +756,7 @@ int main ( int argc, char **argv ) {
 	    case 'h':
 	    case '?':
 	    default:
-		(void) printf("usage: %s [-n nitems] [-s seed] [-V]\n", argv[0]);
+		(void) printf("usage: %s [-f nkifile] [-n nitems] [-s seed] [-V]\n", argv[0]);
 		exit(EXIT_SUCCESS);
 	    }
 	}
